@@ -40,6 +40,7 @@
 #include <errno.h>
 #include <syslog.h>
 #include <locale.h>
+#include <dirent.h>
 
 /* This should be moved to auth.c I suppose */
 
@@ -395,6 +396,43 @@ gdm_final_cleanup (void)
 #endif  /* HAVE_LOGINDEVPERM */
 }
 
+#ifdef sun
+void
+gdm_rmdir(char *thedir)
+{
+    DIR *odir;
+    struct stat buf;
+    struct dirent *dp;
+    char thefile[FILENAME_MAX];
+
+    if ((stat(thedir, &buf) == -1) || ! S_ISDIR(buf.st_mode))
+      return ;
+
+    if ((rmdir(thedir) == -1) && (errno == EEXIST))
+    {
+      odir = opendir(thedir);
+      do {
+        errno = 0;
+        if ((dp = readdir(odir)) != NULL)
+        {
+          if (strcmp(dp->d_name, ".") == 0 ||
+              strcmp(dp->d_name, "..") == 0)
+                continue ;
+          snprintf(thefile, FILENAME_MAX, "%s/%s", thedir, dp->d_name);
+          if (stat(thefile, &buf) == -1)
+            continue ; 
+          if (S_ISDIR(buf.st_mode))
+            gdm_rmdir(thefile);
+          else
+            g_unlink(thefile);
+        }
+      } while (dp != NULL);
+      closedir(odir);
+      rmdir(thedir);
+    }
+}
+#endif
+
 static gboolean
 deal_with_x_crashes (GdmDisplay *d)
 {
@@ -3186,7 +3224,6 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 		gboolean sysmenu;
 
 		disp = gdm_connection_get_display (conn);
-		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 
 		/* Only allow locally authenticated connections */
 		if ( ! GDM_CONN_AUTHENTICATED (conn) ||
@@ -3198,6 +3235,7 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 			return;
 		}
 
+		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 		msg = g_string_new ("OK");
 
 		logout_action = disp->logout_action;
@@ -3237,7 +3275,6 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 		gboolean sysmenu;
 
 		disp = gdm_connection_get_display (conn);
-		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 
 		/* Only allow locally authenticated connections */
 		if ( ! GDM_CONN_AUTHENTICATED(conn) ||
@@ -3250,6 +3287,7 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 			return;
 		}
 
+		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 		if (strcmp (action, GDM_SUP_LOGOUT_ACTION_NONE) == 0) {
 			disp->logout_action = GDM_LOGOUT_ACTION_NONE;
 			was_ok = TRUE;
@@ -3290,7 +3328,6 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 		gboolean sysmenu;
 
 		disp = gdm_connection_get_display (conn);
-		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 
 		/* Only allow locally authenticated connections */
 		if ( ! GDM_CONN_AUTHENTICATED(conn) ||
@@ -3303,6 +3340,7 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 			return;
 		}
 
+		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 		if (strcmp (action, GDM_SUP_LOGOUT_ACTION_NONE) == 0) {
 			safe_logout_action = GDM_LOGOUT_ACTION_NONE;
 			was_ok = TRUE;
